@@ -117,13 +117,19 @@ void InterfaceNotificationHost::interfaceConnectionActivationStateChanged(Knm::I
             m_activating.remove(ic);
             KNotification::event(Event::Connected, m_interfaceNameLabel, i18nc("@info:status Notification text when a connection has been activated","%1 activated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, m_manager->componentData());
             break;
+        case Knm::InterfaceConnection::Deactivating:
+            // Ignored.
+            break;
+        case Knm::InterfaceConnection::Deactivated:
+            m_activating.remove(ic);
+            KNotification::event(Event::Disconnected, m_interfaceNameLabel, i18nc("@info:status Notification text when deactivating a connection","%1 deactivated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, m_manager->componentData());
+            break;
         case Knm::InterfaceConnection::Unknown:
             m_activating.remove(ic);
             if (ic->connectionType() != Knm::Connection::Wireless || Solid::Control::NetworkManagerNm09::isWirelessHardwareEnabled()) {
-                if (ic->oldActivationState() == Knm::InterfaceConnection::Activating)
+                if (ic->oldActivationState() == Knm::InterfaceConnection::Activating) {
                     KNotification::event(Event::ConnectFailed, m_interfaceNameLabel, i18nc("@info:status Notification text when connection has failed","Connection %1 failed", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, m_manager->componentData());
-                else
-                    KNotification::event(Event::Disconnected, m_interfaceNameLabel, i18nc("@info:status Notification text when deactivating a connection","%1 deactivated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, m_manager->componentData());
+                }
             }
             break;
     }
@@ -449,13 +455,17 @@ void NotificationManager::handleUpdate(Knm::Activatable *activatable)
                     kDebug() << ic->connectionName() << "is activated";
                     KNotification::event(Event::Connected, QString(), i18nc("@info:status Notification text when a connection has been activated","%1 activated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, componentData());
                     break;
+                case Knm::InterfaceConnection::Deactivating:
+                    // Ignored.
+                    break;
+                case Knm::InterfaceConnection::Deactivated:
+                    KNotification::event(Event::Disconnected, QString(), i18nc("@info:status Notification text when deactivating a connection","%1 deactivated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, componentData());
+                    break;
                 case Knm::InterfaceConnection::Unknown:
                     kDebug() << ic->connectionName() << "is unknown";
-                    if (ic->oldActivationState() == Knm::InterfaceConnection::Activating)
+                    if (ic->oldActivationState() == Knm::InterfaceConnection::Activating) {
                         KNotification::event(Event::ConnectFailed, QString(), i18nc("@info:status Notification text when connection has failed","Connection %1 failed", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, componentData());
-                    else
-                        KNotification::event(Event::Disconnected, QString(), i18nc("@info:status Notification text when deactivating a connection","%1 deactivated", ic->connectionName()), KIcon(Knm::Connection::iconName(ic->connectionType())).pixmap(QSize(iconSize,iconSize)), 0, KNotification::CloseOnTimeout, componentData());
-                    break;
+                    }
             }
         }
     }
